Example Python Scripts
======================

Various example scripts are located in the directory ``doc/examples/``, e.g.

* :download:`examples/horizontal_plane_arrays.py`:  Computes the sound fields
  for various techniques, virtual sources and loudspeaker array configurations
* :download:`examples/animations_pulsating_sphere.py`: Creates animations of a
  pulsating sphere, see also `the corresponding Jupyter notebook
  <examples/animations-pulsating-sphere.ipynb>`__
* :download:`examples/soundfigures.py`:  Illustrates the synthesis of sound
  figures with Wave Field Synthesis
